@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw[$VERSION];
 
-$VERSION = '0.08';
+$VERSION = '0.10';
 
 my $tables = {
    mods => [
@@ -30,6 +30,29 @@ my $tables = {
    ],
 };
 
+my $indexes = {
+    mods => [
+      'CREATE INDEX mods_mod_name ON mods ( mod_name )',
+      'CREATE INDEX mods_dist_name ON mods ( dist_name )',
+      'CREATE INDEX mods_dist_vers ON mods ( dist_vers )',
+      'CREATE INDEX mods_all ON mods ( mod_name, dist_name, dist_vers )',
+    ],
+    dists => [
+      'CREATE INDEX dists_dist_name ON dists ( dist_name )',
+      'CREATE INDEX dists_dist_vers ON dists ( dist_vers )',
+      'CREATE INDEX dists_cpan_id ON dists ( cpan_id )',
+      'CREATE INDEX dists_all ON dists ( dist_name, dist_vers )',
+    ],
+    auths => [
+      'CREATE INDEX auths_cpan_id ON auths ( cpan_id )',
+    ],
+};
+
+# make the temp mappings
+foreach my $k ( qw( mods dists auths ) ) {
+  $tables->{ 'tmp_' . $k } = $tables->{ $k };
+}
+
 sub table {
   return unless @_;
   my $table = shift;
@@ -42,6 +65,15 @@ sub table {
   return $sql;
 }
 
+sub index {
+  return unless @_;
+  my $table = shift;
+  $table = shift if $table->isa(__PACKAGE__);
+  return unless $table;
+  return unless exists $indexes->{ $table };
+  return [ @{ $indexes->{ $table } } ];
+}
+
 sub tables {
   return sort keys %{ $tables };
 }
@@ -78,15 +110,23 @@ Takes one argument, the name of a table to lookup.
 
 Returns a SQL statement that can be used to create the table.
 
+=item C<index>
+
+Takes one argument, the name of a table to lookup.
+
+Returns an arrayref of SQL statements to create the indexes for the table.
+
 =back
 
 =head1 AUTHOR
 
 Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
 
+Apocalypse <apocal@cpan.org>
+
 =head1 LICENSE
 
-Copyright E<copy> Chris Williams
+Copyright E<copy> Chris Williams and Apocalypse
 
 This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
 
